/*********************************************************************
 * Job Ticket API (JTAPI)                                            
 *                                                                   
 * Copyright (c) 2003 International Business Machines Corp.          
 * Copyright (c) 2003 Free Standards Group.          
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *********************************************************************/

#ifndef FSGJT_ATTRIBUTE_H
#define FSGJT_ATTRIBUTE_H

#include <fsgjt.h>
#include <fsgjt_enums.h>

/************************************************************
 * fsgjtNewAttribute - Creates a new Attribute object having 
 * the provided attribute name, value type, and value.
 *
 * param (output) fsgjt_attribute_t* - Pointer to the new 
 *      attribute is returned. 
 * param (input) char* name - Name for the new attribute to 
 *      create
 * param (input) char* type - Type for the new attribute
 *      (use ValueTypeEnum)
 * param (input) void* value - Pointer to the value for this 
 *      attribute. Multiple values should be added with the 
 *      add() function.
 *
 * return fsgjt_return_code_t - FSGJT_OK on success
 ************************************************************/
fsgjt_return_code_t fsgjtNewAttribute(
               fsgjt_attribute_t* attribute, 
               char* name, 
               char* type, 
               void* value);

/************************************************************
 * fsgjtDestroyAttribute - Free the memory used by the 
 * Attribute.
 *
 * param (input) fsgjt_attribute_t attribute - Attribute to 
 *      free
 *
 * return fsgjt_return_code_t - FSGJT_OK on success
 ************************************************************/
fsgjt_return_code_t fsgjtDestroyAttribute(
               fsgjt_attribute_t attribute);

/************************************************************
 * fsgjtAddValue - Add an additional value to this Attribute.
 *
 * param (input) fsgjt_attribute_t attribute - Attribute to
 *      add the provided value to 
 * param (input) void* value - Pointer to value to add
 *
 * return fsgjt_return_code_t - FSGJT_OK on success
 ************************************************************/
fsgjt_return_code_t fsgjtAddValue(
               fsgjt_attribute_t attribute, 
               void* value);

/************************************************************
 * fsgjtAttributesEqual - Checks the equality of the provided 
 * Attributes. All data members of the Attribute must be 
 * equal for the Attributes to be equal.
 *
 * param (input) fsgjt_attribute_t attr1  
 * param (input) fsgjt_attribute_t attr2  
 *
 * return fsgjt_boolean_t - true if the Attributes are equal
 ************************************************************/
fsgjt_boolean_t fsgjtAttributesEqual(
               fsgjt_attribute_t attr1,
               fsgjt_attribute_t attr2);

/************************************************************
 * fsgjtGetName - Get the name of the Attribute.
 *
 * param (input) fsgjt_attribute_t attribute - Attribute 
 *      whose name to get
 *
 * return char* - Name of the attribute
 ************************************************************/
char* fsgjtGetName(fsgjt_attribute_t attribute);

/************************************************************
 * fsgjtGetNumValues - Returns the number of values that the 
 * Attribute contains.
 *
 * param (input) fsgjt_attribute_t attribute - Attribute 
 *      whose number of values to get
 *
 * return int - Number of values
 ************************************************************/
int fsgjtGetNumValues(fsgjt_attribute_t attribute);

/************************************************************
 * fsgjtGetValueType - Returns the type of the Attribute's 
 * values.
 *
 * param (input) fsgjt_attribute_t attribute - Attribute 
 *       whose value type to get
 *
 * return char* - Type of this Attribute'e values
 ************************************************************/
char* fsgjtGetValueType(fsgjt_attribute_t attribute);

/************************************************************
 * fsgjtHasNextValue - Used to iterate over the Attribute's 
 * values. Returns true while there are more values.
 *
 * param (input) fsgjt_attribute_t attribute - Attribute 
 *      to test to see if there is another value
 *
 * return fsgjt_boolean_t - true while there are more 
 *        values
 ************************************************************/
fsgjt_boolean_t fsgjtHasNextValue(fsgjt_attribute_t attribute);

/************************************************************
 * fsgjtNextValue - Return the next value of the Attribute.
 *
 * param (input) fsgjt_attribute_t attribute - Attribute 
 *       shoe next value is to be returned
 *
 * return void* - Pointer to the next value
 ************************************************************/
void* fsgjtNextValue(fsgjt_attribute_t attribute);

/************************************************************
 * fsgjtResetIterator - Reset the iterator to point to the
 * first value of the Attribute.
 *
 * param (input) fsgjt_attribute_t attribute - Attribute 
 *      to reset
 *
 * return - no return
 ************************************************************/
void fsgjtResetIterator(fsgjt_attribute_t attr);

#endif /* FSGJT_ATTRIBUTE_H */


