/*********************************************************************
 * Job Ticket API (JTAPI)                                            
 *                                                                   
 * Copyright (c) 2003 International Business Machines Corp.          
 * Copyright (c) 2003 Free Standards Group.          
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *********************************************************************/

#ifndef FSGJT_JOB_TICKET_INFO_H
#define FSGJT_JOB_TICKET_INFO_H

#include <stdio.h>
#include <fsgjt.h>

/* Defined constant to uniquely identify this type of JTAPI object */
#define FSGJT_JOB_TICKET_INFO_OBJECT_TYPE    "FSGJT_JOB_TICKET_INFO"

/************************************************************
 * Job Ticket Info attributes
 ***********************************************************/
#define FSGJT_JT_API_VERSION      "jt-api-version"
#define FSGJT_JT_COMMENT          "jt-comment"
#define FSGJT_JT_LENGTH_UNIT      "jt-length-unit"
#define FSGJT_JT_TYPE_AND_VERSION "jt-type-and-version"

/************************************************************
 * Other constants
 ***********************************************************/
/* The jt-api-version attribute is set to the following value. */    
#define FSGJT_API_VERSION        "alpha"

/************************************************************
 * fsgjtNewJobTicketInfoFromURI - Creates a JobTicketInfo 
 * object from the job ticket file at the provided URI. Other 
 * JTAPI objects are also created based on the information in
 * the job ticket file.
 *
 * param (output) fsgjt_object_t* jobTicketInfo - Pointer to 
 *      the JobTicketInfo to create
 * param (input) char* uri - URI where job ticket file 
 *      resides
 * param (input) char* typeAndVersion - Type and version of 
 *      this job ticket (use JobTicketTypeVersionEnum).
 *
 * return fsgjt_status_t
 ***********************************************************/
fsgjt_status_t fsgjtNewJobTicketInfoFromURL(
               fsgjt_object_t* jobTicketInfo,
               char* uri,
               char* typeAndVersion);

/************************************************************
 * fsgjtNewJobTicketInfoFromBuffer - Creates a JobTicketInfo 
 * object from the provided buffer that contains a job 
 * ticket. Other JTAPI objects are also created based on the 
 * information in the job ticket buffer.
 *
 * param (output) fsgjt_object_t* jobTicketInfo - Pointer to 
 *      the JobTicketInfo to create
 * param (input) char** buffer - Buffer that contains the 
 *      job ticket
 * param (input) size_t bufferSize - Size of the buffer 
 * param (input) char* typeAndVersion - Type and version of 
 *      this job ticket (use JobTicketTypeVersionEnum).
 *
 * return fsgjt_status_t
 ***********************************************************/
fsgjt_status_t fsgjtNewJobTicketInfoFromBuffer(
               fsgjt_object_t* jobTicketInfo,
               char** buffer,
               size_t bufferSize,
               char* typeAndVersion);

/************************************************************
 * fsgjtNewJobTicketInfoFromJob - Creates a JobTicketInfo 
 * object using the provided Job object. Used when a new job 
 * ticket is being created. The Job object must be created 
 * first.
 *
 * param (output) fsgjt_object_t* jobTicketInfo - Pointer to 
 *      the new JobTicketInfo to create
 * param (input) fsgjt_object_t job - Job object that this 
 *      JobTicketInfo is to contain
 * param (input) char* typeAndVersion - Type and version of 
 *      this job ticket (use JobTicketTypeVersionEnum).
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewJobTicketInfoFromJob(
               fsgjt_object_t* jobTicketInfo,
               fsgjt_object_t job,
               char* typeAndVersion);

/************************************************************
 * fsgjtGetJob - Returns a pointer to the job that this 
 * JobTicketInfo contains.
 *
 * param (input) fsgjt_object_t jobTicketInfo - JobTicketInfo
 *      to get the job from
 * param (output) fsgjt_object_t* job - Pointer to this 
 *      JobTicketInfo's job
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtGetJob(
               fsgjt_object_t jobTicketInfo,
               fsgjt_object_t* job);

/************************************************************
 * fsgjtWriteJobTicketBuffer - Writes a job ticket to the 
 * provided buffer.
 *
 * param (input) fsgjt_object_t jobTicketInfo - JobTicketInfo 
 *      from which the job ticket is to be written
 * param (output) char** buffer - Pointer to buffer to write 
 *      the job ticket to. The buffer must be created by the 
 *      caller.
 * param (input) size_t bufferSize - Size of the buffer that 
 *      caller created
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtWriteJobTicketBuffer(
               fsgjt_object_t jobTicketInfo,
               char** buffer,
               size_t bufferSize);

/************************************************************
 * fsgjtWriteJobTicketURI - Wrtes a job ticket at the 
 * provided URI.
 *
 * param (input) fsgjt_object_t jobTicketInfo - JobTicketInfo  
 *      from which the job ticket is to be written
 * param (output) char* uri - URI of the job ticket that is
 *      to be created from the JobTicketInfo. 
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtWriteJobTicketURI(
               fsgjt_object_t jobTicketInfo,
               char* uri);

#endif /* FSGJT_JOB_TICKET_INFO_H */
